@@ -1,3 +1,41 @@
+
+
+
+#' @title Detect NA in a vector
+#'
+#' @param vect A vector, whose components are allowed to be numeric, character, etc.
+#'
+#' @return A logical. If \code{vect} contains at least one \code{NA}, then \code{TRUE}. Otherwise \code{FALSE}.
+#' @export
+#'
+#' @examples
+#'
+#'  is_na_in_vector(  c(NA,1)      )
+#'
+#'  is_na_in_vector(  c(6,1)      )
+#'
+#'  is_na_in_vector(  c(1:5,NA,1)      )
+#'
+#'  is_na_in_vector(  c(1:5,1)      )
+#'
+#'  is_na_in_vector(  c(1:5,NA,1,NA)      )
+#'
+#'  is_na_in_vector(  c(1:51,"asdfg")      )
+#'
+#'  is_na_in_vector(  c(1:5,NA,1,NA,"asdfg")      )
+#'
+is_na_in_vector <- function(vect) {
+  !as.logical(  prod( !is.na(vect  )  )   )
+}
+
+
+
+
+
+
+
+
+
 #' @title is.logical(0)
 #' @description When object is created by the codes \code{ x <- integer(); y <- list(); z <- logical()},
 #' and if the values is not substituted, then this function return \code{TRUE}.
