@@ -2,6 +2,8 @@
 #' @title plot datasets using calculation of ppp
 #'
 #' @inheritParams DrawCurves
+#' @param verbose A logical, whether title in plot is verbose or not.
+#' @param colorindex A positive integer, indicating the color of scatter plots.
 #'
 #' @return null
 #' @export
@@ -21,10 +23,14 @@
 #'# Plot samples synthesized from posterior predictive distribution (PPD)
 #'
 #'plot_dataset_of_ppp(f)
+#'plot_dataset_of_ppp(f,colorindex = 1)
+#'plot_dataset_of_ppp(f,colorindex = 2)
+#'plot_dataset_of_ppp(f,colorindex = 3)
+#'plot_dataset_of_ppp(f,colorindex = 4)
 #'
 #'}#dontrun
 #'
-plot_dataset_of_ppp <-function(StanS4class,summary =FALSE){
+plot_dataset_of_ppp <-function(StanS4class,summary =FALSE, verbose = FALSE,colorindex = 6){
   # browser()
   f <- StanS4class
   fit <-f
@@ -41,12 +47,21 @@ p.value <- ee$p_value_logicals.EAP
 # Then, it causes that FPF and TPF include NaN.
 #  Then the author should delete such NaN.
 
-FPF <- e$FPF_post_pred
+
+
+FPF <- e$FPF_post_pred # Three index array
 TPF <- e$TPF_post_pred
 
-FPF<- matrix(aperm(FPF, c(1,3,2)), ncol = 3)
-TPF<- matrix(aperm(TPF, c(1,3,2)), ncol = 3)
+# FPF<- matrix(aperm(FPF, c(1,3,2)), ncol = 3)
+# TPF<- matrix(aperm(TPF, c(1,3,2)), ncol = 3)
 
+C <- f@dataList$C#2021Nov26
+
+
+FPF<- matrix(aperm(FPF, c(1,3,2)), ncol = C)#2021Nov26 # Three index array are converted to two indices matrix by this command line.
+TPF<- matrix(aperm(TPF, c(1,3,2)), ncol = C)#2021Nov26
+
+# browser()
 
 FPF <- t(FPF)
 TPF <- t(TPF)
@@ -55,15 +70,15 @@ TPF <- t(TPF)
 FPF <- as.vector(FPF)
 TPF <- as.vector(TPF)
 # browser()
-if( is.nan( max(FPF) ) ) color_message("0 Poisson rates in FPF may appear, maybe or somethings happened in sampling from PPD ")
-if( is.nan( max(TPF) ) ) color_message("0 hit rates in TPF may appear, maybe or somethings happened in sampling from PPD ")
+if( is.nan( max(FPF) ) ) color_message("0 Poisson rates in FPF may occur, somethings happened in sampling from PPD ")
+if( is.nan( max(TPF) ) ) color_message("0 hit rates in TPF may occur, somethings happened in sampling from PPD ")
 
 
 DF <- data.frame(FPF = FPF, TPF = TPF)
 DF_NaN_omitted <- stats::na.omit(DF)
 FPF <- DF_NaN_omitted$FPF
 TPF <- DF_NaN_omitted$TPF
-
+# prod(as.vector(DF  ==DF_NaN_omitted))
 
 
 # NaN is omitted here -------------------------------------------------
@@ -71,7 +86,7 @@ TPF <- DF_NaN_omitted$TPF
 
 
 
-C <- f@dataList$C
+# C <- f@dataList$C#2021Nov26
 N<-C
 c<-C:1
 NL <- f@dataList$NL
@@ -118,7 +133,7 @@ xlim <-c(lower_lim_x,upper_lim_x)
 
 
 main <- paste("P value = ", p.value)
-
+ if(verbose)   main <-  substitute(paste("Goodness of fit: Post. Pred. Pvalue = ", pvalue ," =",integral( integral( iota*(chi^2*(D*"|"* theta) - chi^2*(D[obs]*"|"* theta) )*pi(D*"|"*theta)*pi(theta*"|"*D[obs])*d*theta*d*D, Theta, .  ), "Datasets", . ) , " = ",pvalue ),list( pvalue=p.value)  )#2021Nov25
 
 BayesianFROC::small_margin()
 # browser()
@@ -138,7 +153,10 @@ if (fit@studyDesign=="srsc.per.image")    xlab = 'Replicated false positives per
 if (fit@studyDesign=="srsc.per.lesion" )    xlab = 'Replicated false positives per nodule from the posterior predictive distribution.'
 ylab<- "Replicated cumulative hits per lesion"
 BayesianFROC::small_margin()
-plot(FPF,TPF, pch=20, col=grDevices::rainbow(C+6, alpha=0.2)[group],
+plot(FPF,TPF, pch=20,
+     # col=grDevices::rainbow(C+6, alpha=0.2)[group],
+     col=grDevices::rainbow(C+colorindex, alpha=0.2)[group],
+
      cex=0.8, xlab=xlab, ylab=ylab, main =main,
      # xlim = c(0, upper_lim_x),
      # ylim = c(0,upper_lim_y)
@@ -204,9 +222,9 @@ plot(fit@metadata$ff, fit@metadata$hh,col="green",
 df <- data.frame(FPF =FPF,TPF=TPF)
 
 # if(summary)message("p value of chi square goodness of fit = ", p.value)
-if(p.value>0.05)message("p value = ", crayon::bgBlack$red$bold$underline$italic(p.value), ", which is for the chi square goodness of fit statistic whose null hypthothesis is that the model is fitted. Now, calculation shows that the p value is not less than 0.05, so, we do not need to reject the null hypothesis .... maybe ... love you. ")
+if(p.value>0.05)message("p value = ", crayon::bgBlack$red$bold$underline$italic(p.value), ", which is for the chi square goodness of fit statistic whose null hypthothesis is that the model is fitted well. Now, calculation shows that the p value is not less than 0.05, so, we do not need to reject the null hypothesis .... maybe ... love you. ")
 
-if(p.value<0.05)message("p value = ", crayon::bgBlack$red$bold$underline$italic(p.value), ", which is for the chi square goodness of fit statistic whose null hypthothesis is that the model is fitted. Now, unfortunately, calculation shows that the p value is less than 0.05, the null hypothesis may be rejected by someone who loves frequentist schemes ... maybe ...I love you. ")
+if(p.value<0.05)message("p value = ", crayon::bgBlack$red$bold$underline$italic(p.value), ", which is for the chi square goodness of fit statistic whose null hypthothesis is that the model is fitted well. Now, unfortunately, calculation shows that the p value is less than 0.05, the null hypothesis may be rejected by someone who loves frequentist schemes ... maybe ...I love you. ")
 
 if(summary){return(list(df=df,p.value =p.value))
 }else {invisible(df)}
