@@ -18,4 +18,4 @@ Simulation_Based_Calibration_single_reader_single_modality_via_rstan_sbc(
   stanModel = stanModel,
   ite     = 233, NI=1111, NL=1111,
   M       = 1111,
-  epsilon = 0.04,BBB = 1.1,AAA =0.0091,sbc_from_rstan = T)
+  epsilon = 0.04,BBB = 1.1,AAA =0.0091,sbc_from_rstan = TRUE)
